/* -*- mode: c++; c-basic-offset: 4; -*- */
#include "epoch.hh"
#include <map>
#include <string>
#include <stdexcept>

namespace sends {

    /**  The epoch table keepsa map of defined epochs.
     */
    class epoch_table {
    public:
	epoch_table(void);
	~epoch_table(void);
	void add(const std::string& name, const epoch& epic);
	bool defined(const std::string& name) const;
	std::ostream& display(std::ostream&) const;
	const epoch& operator[](const std::string& name) const;
    private:
	typedef std::map<std::string, epoch> epoch_map;
	typedef epoch_map::const_iterator    const_epoch_iter;
    private:
	epoch_map  mTable;
    };

    //==================================  inline methods.
    inline bool
    epoch_table::defined(const std::string& name) const {
	return mTable.find(name) != mTable.end();
    }

    inline const epoch&
    epoch_table::operator[](const std::string& name) const {
	const_epoch_iter iter =  mTable.find(name);
	if (iter != mTable.end()) return iter->second;
	throw std::runtime_error("Epoch name not found"); 
    }

    extern epoch_table Epoch_Table;

} //namespace sends
